@@ -1,5 +1,5 @@
 # This file is part of ReText
-# Copyright: 2013-2015 Dmitry Shachnev
+# Copyright: 2013-2017 Dmitry Shachnev
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
-from ReText import globalSettings, icon_path
+from ReText import globalSettings, getBundledIcon
 from ReText.icontheme import get_icon_theme
 from markups.common import CONFIGURATION_DIR
 from os.path import join
@@ -67,11 +67,13 @@ class ConfigDialog(QDialog):
 		self.options = (
 			(self.tr('Behavior'), None),
 			(self.tr('Automatically save documents'), 'autoSave'),
+			(self.tr('Automatically open last documents on startup'), 'openLastFilesOnStartup'),
 			(self.tr('Restore window geometry'), 'saveWindowGeometry'),
 			(self.tr('Use live preview by default'), 'livePreviewByDefault'),
 			(self.tr('Open external links in ReText window'), 'handleWebLinks'),
 			(self.tr('Markdown syntax extensions (comma-separated)'), 'markdownExtensions'),
 			(None, 'markdownExtensions'),
+			(self.tr('Enable synchronized scrolling for Markdown'), 'syncScroll'),
 		#	(self.tr('Default Markdown file extension'), 'markdownDefaultFileExtension'),
 		#	(self.tr('Default reStructuredText file extension'), 'restDefaultFileExtension'),
 			(self.tr('Editor'), None),
@@ -79,7 +81,7 @@ class ConfigDialog(QDialog):
 			(self.tr('Show line numbers'), 'lineNumbersEnabled'),
 			(self.tr('Tab key inserts spaces'), 'tabInsertsSpaces'),
 			(self.tr('Tabulation width'), 'tabWidth'),
-			(self.tr('Display right margin at column'), 'rightMargin'),
+			(self.tr('Draw vertical line at column'), 'rightMargin'),
 			(self.tr('Interface'), None),
 			(self.tr('Icon theme name'), 'iconTheme'),
 			(self.tr('Stylesheet file'), 'styleSheet', True),
@@ -154,7 +156,7 @@ class ConfigDialog(QDialog):
 	def applySettings(self):
 		QIcon.setThemeName(globalSettings.iconTheme)
 		if QIcon.themeName() in ('hicolor', ''):
-			if not QFile.exists(icon_path + 'document-new.png'):
+			if not QFile.exists(getBundledIcon('document-new')):
 				QIcon.setThemeName(get_icon_theme())
 		try:
 			extsFile = open(MKD_EXTS_FILE, 'w')
@@ -166,4 +168,5 @@ class ConfigDialog(QDialog):
 			print(e, file=sys.stderr)
 		for tab in self.parent.iterateTabs():
 			tab.editBox.updateFont()
+			tab.editBox.viewport().update()
 		self.parent.updateStyleSheet()
