@@ -127,7 +127,7 @@ def _determineNextEdge(rows, rowShifts, offset):
 	for row, rowShift in zip(rows, rowShifts):
 		if rowShift != 0:
 			edge = row.text.find('|', offset)
-			if edge != -1 and (nextedge == None or edge < nextedge):
+			if edge != -1 and (nextedge is None or edge < nextedge):
 				nextedge = edge
 	return nextedge
 
@@ -190,3 +190,29 @@ def adjustTableToChanges(doc, pos, editsize, markupClass):
 
 		cursor = QTextCursor(doc)
 		_performEdits(cursor, rows, editLists, editedlineindex, editsize)
+
+def handleReturn(cursor, markupClass, newRow):
+	if markupClass not in (MarkdownMarkup, ReStructuredTextMarkup):
+		return False
+	positionInBlock = cursor.positionInBlock()
+	cursor.select(QTextCursor.BlockUnderCursor)
+	oldLine = cursor.selectedText().lstrip('\u2029')
+	if not ('| ' in oldLine or ' |' in oldLine):
+		cursor.setPosition(cursor.block().position() + positionInBlock)
+		return False
+	indent = 0
+	while oldLine[indent] in ' \t':
+		indent += 1
+	indentChars, oldLine = oldLine[:indent], oldLine[indent:]
+	newLine = ''.join('|' if c in '+|' else ' ' for c in oldLine).rstrip()
+	cursor.movePosition(QTextCursor.EndOfBlock)
+	if newRow and markupClass == MarkdownMarkup:
+		sepLine = ''.join(c if c in ' |' else '-' for c in oldLine)
+		cursor.insertText('\n' + indentChars + sepLine)
+	elif newRow:
+		sepLine = ''.join('+' if c in '+|' else '-' for c in oldLine)
+		cursor.insertText('\n' + indentChars + sepLine)
+	cursor.insertText('\n' + indentChars + newLine)
+	positionInBlock = min(positionInBlock, len(indentChars + newLine))
+	cursor.setPosition(cursor.block().position() + positionInBlock)
+	return True
