@@ -57,8 +57,8 @@ class ReTextWindow(QMainWindow):
 			self.restoreGeometry(globalSettings.windowGeometry)
 		else:
 			self.move((screenRect.width()-self.width())/2, (screenRect.height()-self.height())/2)
-		if not screenRect.contains(self.geometry()):
-			self.showMaximized()
+			if not screenRect.contains(self.geometry()):
+				self.showMaximized()
 		if sys.platform.startswith('darwin'):
 			# https://github.com/retext-project/retext/issues/198
 			searchPaths = QIcon.themeSearchPaths()
@@ -363,7 +363,7 @@ class ReTextWindow(QMainWindow):
 			try:
 				enchant.Dict(self.sl or None)
 			except enchant.errors.Error as e:
-				warnings.warn(e, RuntimeWarning)
+				warnings.warn(str(e), RuntimeWarning)
 				globalSettings.spellCheck = False
 			if globalSettings.spellCheck:
 				self.actionEnableSC.setChecked(True)
