@@ -68,7 +68,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="103"/>
+        <location filename="config.py" line="104"/>
         <source>Help</source>
         <translation type="unfinished">Ajuda</translation>
     </message>
@@ -87,6 +87,11 @@
         <source>Draw vertical line at column</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Automatically open last documents on startup</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
@@ -130,12 +135,12 @@
 <context>
     <name>ReTextEdit</name>
     <message>
-        <location filename="editor.py" line="285"/>
+        <location filename="editor.py" line="295"/>
         <source>Save image</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="editor.py" line="285"/>
+        <location filename="editor.py" line="295"/>
         <source>Images (*.png *.jpg)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -143,12 +148,12 @@
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="tab.py" line="177"/>
+        <location filename="tab.py" line="183"/>
         <source>New document</source>
         <translation>Document nou</translation>
     </message>
     <message>
-        <location filename="tab.py" line="182"/>
+        <location filename="tab.py" line="188"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>No s&apos;ha pogut analitzar el contingut del fitxer. Comproveu que teniu instal·lat el  &lt;a href=&quot;%s&quot;&gt;mòdul  necessari&lt;/a&gt;.</translation>
     </message>
@@ -156,435 +161,460 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="81"/>
+        <location filename="window.py" line="85"/>
         <source>File toolbar</source>
         <translation>Barra d&apos;eines Fitxer</translation>
     </message>
     <message>
-        <location filename="window.py" line="83"/>
+        <location filename="window.py" line="87"/>
         <source>Edit toolbar</source>
         <translation>Barra d&apos;eines Edita</translation>
     </message>
     <message>
-        <location filename="window.py" line="85"/>
+        <location filename="window.py" line="89"/>
         <source>Search toolbar</source>
         <translation>Barra d&apos;eines de Cerca</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
+        <location filename="window.py" line="93"/>
         <source>New</source>
         <translation>Nou</translation>
     </message>
     <message>
-        <location filename="window.py" line="92"/>
+        <location filename="window.py" line="96"/>
         <source>Open</source>
         <translation>Obre</translation>
     </message>
     <message>
-        <location filename="window.py" line="101"/>
+        <location filename="window.py" line="105"/>
         <source>Save</source>
         <translation>Desa</translation>
     </message>
     <message>
-        <location filename="window.py" line="105"/>
+        <location filename="window.py" line="109"/>
         <source>Save as</source>
         <translation>Anomena i desa</translation>
     </message>
     <message>
-        <location filename="window.py" line="111"/>
+        <location filename="window.py" line="115"/>
         <source>Print</source>
         <translation>Imprimeix</translation>
     </message>
     <message>
-        <location filename="window.py" line="114"/>
+        <location filename="window.py" line="118"/>
         <source>Print preview</source>
         <translation>Imprimeix la vista prèvia</translation>
     </message>
     <message>
-        <location filename="window.py" line="116"/>
+        <location filename="window.py" line="120"/>
         <source>View HTML code</source>
         <translation>Veure el codi HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="121"/>
+        <location filename="window.py" line="125"/>
         <source>Find text</source>
         <translation>Cerca el text</translation>
     </message>
     <message>
-        <location filename="window.py" line="125"/>
+        <location filename="window.py" line="129"/>
         <source>Preview</source>
         <translation>Vista prèvia</translation>
     </message>
     <message>
-        <location filename="window.py" line="135"/>
+        <location filename="window.py" line="139"/>
         <source>Live preview</source>
         <translation>Vista prèvia en directe</translation>
     </message>
     <message>
-        <location filename="window.py" line="149"/>
+        <location filename="window.py" line="153"/>
         <source>Fullscreen mode</source>
         <translation>Mode de pantalla completa</translation>
     </message>
     <message>
-        <location filename="window.py" line="159"/>
+        <location filename="window.py" line="163"/>
         <source>Quit</source>
         <translation>Surt</translation>
     </message>
     <message>
-        <location filename="window.py" line="162"/>
+        <location filename="window.py" line="166"/>
         <source>Undo</source>
         <translation>Desfés</translation>
     </message>
     <message>
-        <location filename="window.py" line="164"/>
+        <location filename="window.py" line="168"/>
         <source>Redo</source>
         <translation>Refés</translation>
     </message>
     <message>
-        <location filename="window.py" line="166"/>
+        <location filename="window.py" line="170"/>
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="window.py" line="172"/>
         <source>Cut</source>
         <translation>Retalla</translation>
     </message>
     <message>
-        <location filename="window.py" line="170"/>
+        <location filename="window.py" line="174"/>
         <source>Paste</source>
         <translation>Enganxa</translation>
     </message>
     <message>
-        <location filename="window.py" line="180"/>
+        <location filename="window.py" line="184"/>
         <source>Enable</source>
         <translation>Activa</translation>
     </message>
     <message>
-        <location filename="window.py" line="181"/>
+        <location filename="window.py" line="185"/>
         <source>Set locale</source>
         <translation>Estableix l&apos;idioma</translation>
     </message>
     <message>
-        <location filename="window.py" line="182"/>
+        <location filename="window.py" line="186"/>
         <source>Use WebKit renderer</source>
         <translation>Utilitza el renderitzador WebKit</translation>
     </message>
     <message>
-        <location filename="window.py" line="188"/>
+        <location filename="window.py" line="197"/>
         <source>Next</source>
         <translation>Següent</translation>
     </message>
     <message>
-        <location filename="window.py" line="190"/>
+        <location filename="window.py" line="199"/>
         <source>Previous</source>
         <translation>Previ</translation>
     </message>
     <message>
-        <location filename="window.py" line="195"/>
+        <location filename="window.py" line="210"/>
         <source>Get help online</source>
         <translation>Obtingueu ajuda en línia</translation>
     </message>
     <message>
-        <location filename="window.py" line="196"/>
+        <location filename="window.py" line="211"/>
         <source>About ReText</source>
         <translation>Sobre ReText</translation>
     </message>
     <message>
-        <location filename="window.py" line="199"/>
+        <location filename="window.py" line="214"/>
         <source>About Qt</source>
         <translation>Sobre Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="214"/>
+        <location filename="window.py" line="229"/>
         <source>Bold</source>
         <translation>Negreta</translation>
     </message>
     <message>
-        <location filename="window.py" line="216"/>
+        <location filename="window.py" line="231"/>
         <source>Italic</source>
         <translation>Cursiva</translation>
     </message>
     <message>
-        <location filename="window.py" line="218"/>
+        <location filename="window.py" line="233"/>
         <source>Underline</source>
         <translation>Subratllat</translation>
     </message>
     <message>
-        <location filename="window.py" line="230"/>
+        <location filename="window.py" line="245"/>
         <source>Symbols</source>
         <translation>Símbols</translation>
     </message>
     <message>
-        <location filename="window.py" line="235"/>
+        <location filename="window.py" line="250"/>
         <source>File</source>
         <translation>Fitxer</translation>
     </message>
     <message>
-        <location filename="window.py" line="236"/>
+        <location filename="window.py" line="251"/>
         <source>Edit</source>
         <translation>Edita</translation>
     </message>
     <message>
-        <location filename="window.py" line="237"/>
+        <location filename="window.py" line="252"/>
         <source>Help</source>
         <translation>Ajuda</translation>
     </message>
     <message>
-        <location filename="window.py" line="240"/>
+        <location filename="window.py" line="255"/>
         <source>Open recent</source>
         <translation>Obre recents</translation>
     </message>
     <message>
-        <location filename="window.py" line="252"/>
+        <location filename="window.py" line="267"/>
         <source>Export</source>
         <translation>Exporta</translation>
     </message>
     <message>
-        <location filename="window.py" line="273"/>
+        <location filename="window.py" line="288"/>
         <source>Spell check</source>
         <translation>Comprova l&apos;ortografia</translation>
     </message>
     <message>
-        <location filename="window.py" line="284"/>
+        <location filename="window.py" line="299"/>
         <source>Formatting</source>
         <translation>Formata</translation>
     </message>
     <message>
-        <location filename="window.py" line="321"/>
+        <location filename="window.py" line="339"/>
         <source>Search</source>
         <translation>Cerca</translation>
     </message>
     <message>
-        <location filename="window.py" line="323"/>
+        <location filename="window.py" line="344"/>
         <source>Case sensitively</source>
         <translation>Majúscules i minúscules</translation>
     </message>
     <message>
-        <location filename="window.py" line="458"/>
+        <location filename="window.py" line="492"/>
         <source>New document</source>
         <translation>Document nou</translation>
     </message>
     <message>
-        <location filename="window.py" line="622"/>
+        <location filename="window.py" line="664"/>
         <source>Please, save the file somewhere.</source>
         <translation>deseu el fitxer en algun directori</translation>
     </message>
     <message>
-        <location filename="window.py" line="187"/>
+        <location filename="window.py" line="196"/>
         <source>Show directory</source>
         <translation>Mostra el directori</translation>
     </message>
     <message>
-        <location filename="window.py" line="738"/>
+        <location filename="window.py" line="780"/>
         <source>Select one or several files to open</source>
         <translation>Seleccioneu un o més fitxers per obrir</translation>
     </message>
     <message>
-        <location filename="window.py" line="738"/>
+        <location filename="window.py" line="780"/>
         <source>Supported files</source>
         <translation>Fitxers suportats</translation>
     </message>
     <message>
-        <location filename="window.py" line="738"/>
+        <location filename="window.py" line="780"/>
         <source>All files (*)</source>
         <translation>Tots els fitxers (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="797"/>
+        <location filename="window.py" line="839"/>
         <source>Plain text (*.txt)</source>
         <translation>Text pla (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="800"/>
+        <location filename="window.py" line="842"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s fitxers</translation>
     </message>
     <message>
-        <location filename="window.py" line="867"/>
+        <location filename="window.py" line="919"/>
         <source>Save file</source>
         <translation>Desa el fitxer</translation>
     </message>
     <message>
-        <location filename="window.py" line="821"/>
+        <location filename="window.py" line="884"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>No s&apos;ha pogut desar el fitxer perquè només és de lectura</translation>
     </message>
     <message>
-        <location filename="window.py" line="857"/>
+        <location filename="window.py" line="909"/>
         <source>Export document to ODT</source>
         <translation>Exporta el document a ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="857"/>
+        <location filename="window.py" line="909"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Fitxers de text OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="867"/>
+        <location filename="window.py" line="919"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Fitxers HTML (*.html *htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="888"/>
+        <location filename="window.py" line="940"/>
         <source>Export document to PDF</source>
         <translation>Exporta document com a PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="888"/>
+        <location filename="window.py" line="940"/>
         <source>PDF files (*.pdf)</source>
         <translation>Fitxers PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="908"/>
+        <location filename="window.py" line="960"/>
         <source>Print document</source>
         <translation>Imprimeix document</translation>
     </message>
     <message>
-        <location filename="window.py" line="932"/>
+        <location filename="window.py" line="984"/>
         <source>Export document</source>
         <translation>Exporta document</translation>
     </message>
     <message>
-        <location filename="window.py" line="953"/>
+        <location filename="window.py" line="1005"/>
         <source>Failed to execute the command:</source>
         <translation>S&apos;ha produït un error a l&apos;executar el comandament:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1064"/>
+        <location filename="window.py" line="1116"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>S&apos;ha modificat el document.
 Voleu desar els canvis?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1089"/>
+        <location filename="window.py" line="1145"/>
         <source>HTML code</source>
         <translation>Codi HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1100"/>
+        <location filename="window.py" line="1156"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Editor de Markdown i reStructuredText senzill alhora que potent</translation>
     </message>
     <message>
-        <location filename="window.py" line="1100"/>
+        <location filename="window.py" line="1156"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autor: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1100"/>
+        <location filename="window.py" line="1156"/>
         <source>Website</source>
         <translation>Lloc web</translation>
     </message>
     <message>
-        <location filename="window.py" line="1100"/>
+        <location filename="window.py" line="1156"/>
         <source>Markdown syntax</source>
         <translation>Sintaxi markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1100"/>
+        <location filename="window.py" line="1156"/>
         <source>reStructuredText syntax</source>
         <translation>Sintaxi reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="281"/>
+        <location filename="window.py" line="296"/>
         <source>Default markup</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="553"/>
+        <location filename="window.py" line="588"/>
         <source>Preferences</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="95"/>
+        <location filename="window.py" line="99"/>
         <source>Set encoding</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="776"/>
+        <location filename="window.py" line="818"/>
         <source>Select file encoding from the list:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1044"/>
+        <location filename="window.py" line="1096"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="107"/>
+        <location filename="window.py" line="111"/>
         <source>Next tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="window.py" line="113"/>
         <source>Previous tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="140"/>
+        <location filename="window.py" line="144"/>
         <source>Table editing mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="144"/>
+        <location filename="window.py" line="148"/>
         <source>FakeVim mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1028"/>
+        <location filename="window.py" line="1080"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1035"/>
+        <location filename="window.py" line="1087"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="window.py" line="1092"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="117"/>
+        <location filename="window.py" line="121"/>
         <source>Change editor font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="119"/>
+        <location filename="window.py" line="123"/>
         <source>Change preview font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1100"/>
+        <location filename="window.py" line="1156"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="192"/>
+        <location filename="window.py" line="207"/>
         <source>Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="987"/>
+        <location filename="window.py" line="1039"/>
         <source>Alt text</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="988"/>
+        <location filename="window.py" line="1040"/>
         <source>URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="988"/>
+        <location filename="window.py" line="1040"/>
         <source>Link text</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="window.py" line="201"/>
+        <source>Replace</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="203"/>
+        <source>Replace all</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="342"/>
+        <source>Replace with</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="860"/>
+        <source>Cannot save to file which is open in another tab!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="191"/>
+        <source>Use WebEngine (Chromium) renderer</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
