@@ -12,6 +12,11 @@
         <source>Automatically save documents</source>
         <translation>Automaticky ukládat dokumenty</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Automatically open last documents on startup</source>
+        <translation>Automaticky otevírat dokumenty</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Restore window geometry</source>
@@ -27,6 +32,11 @@
         <source>Open external links in ReText window</source>
         <translation>Otevírat externí odkazy v okně ReTextu</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Markdown syntax extensions (comma-separated)</source>
+        <translation>Přípony syntaxe Markdown (oddělené čárkami)</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Enable synchronized scrolling for Markdown</source>
@@ -77,21 +87,11 @@
         <source>Stylesheet file</source>
         <translation>Soubor stylu</translation>
     </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Markdown syntax extensions (comma-separated)</source>
-        <translation>Přípony syntaxe Markdown (oddělené čárkami)</translation>
-    </message>
     <message>
         <location filename="config.py" line="104"/>
         <source>Help</source>
         <translation>Nápověda</translation>
     </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Automatically open last documents on startup</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
@@ -258,7 +258,7 @@
     <message>
         <location filename="window.py" line="144"/>
         <source>Table editing mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Editační mód pro tablet</translation>
     </message>
     <message>
         <location filename="window.py" line="148"/>
@@ -320,6 +320,11 @@
         <source>Use WebKit renderer</source>
         <translation>Použít WebKit k vykreslování</translation>
     </message>
+    <message>
+        <location filename="window.py" line="191"/>
+        <source>Use WebEngine (Chromium) renderer</source>
+        <translation>Použít WebEngine (Chromium) k vykreslování</translation>
+    </message>
     <message>
         <location filename="window.py" line="196"/>
         <source>Show directory</source>
@@ -335,6 +340,16 @@
         <source>Previous</source>
         <translation>Předchozí</translation>
     </message>
+    <message>
+        <location filename="window.py" line="201"/>
+        <source>Replace</source>
+        <translation>Nahradit</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="203"/>
+        <source>Replace all</source>
+        <translation>Nahradit vše</translation>
+    </message>
     <message>
         <location filename="window.py" line="207"/>
         <source>Close</source>
@@ -420,6 +435,11 @@
         <source>Search</source>
         <translation>Najít</translation>
     </message>
+    <message>
+        <location filename="window.py" line="342"/>
+        <source>Replace with</source>
+        <translation>Nahradit s</translation>
+    </message>
     <message>
         <location filename="window.py" line="344"/>
         <source>Case sensitively</source>
@@ -471,6 +491,11 @@
         <source>Save file</source>
         <translation>Uložit soubor</translation>
     </message>
+    <message>
+        <location filename="window.py" line="860"/>
+        <source>Cannot save to file which is open in another tab!</source>
+        <translation>Nelze uložit do souboru, který je otevřený v jiné záložce!</translation>
+    </message>
     <message>
         <location filename="window.py" line="884"/>
         <source>Cannot save to file because it is read-only!</source>
@@ -593,30 +618,5 @@ Do you want to save your changes?</source>
         <source>reStructuredText syntax</source>
         <translation>reStructuredText syntaxe</translation>
     </message>
-    <message>
-        <location filename="window.py" line="201"/>
-        <source>Replace</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="203"/>
-        <source>Replace all</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="342"/>
-        <source>Replace with</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="860"/>
-        <source>Cannot save to file which is open in another tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="191"/>
-        <source>Use WebEngine (Chromium) renderer</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 </TS>
