@@ -12,11 +12,21 @@
         <source>Automatically save documents</source>
         <translation>Sauvegarde automatique des documents</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Automatically open last documents on startup</source>
+        <translation>Ouvrir automatiquement les derniers documents au démarrage</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Restore window geometry</source>
         <translation>Restaurer la taille de la fenêtre</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Use live preview by default</source>
+        <translation>Utiliser l&apos;aperçu dynamique par défaut</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Open external links in ReText window</source>
@@ -25,7 +35,12 @@
     <message>
         <location filename="config.py" line="67"/>
         <source>Markdown syntax extensions (comma-separated)</source>
-        <translation>Extensions liées à la syntaxe Markdown (séparées par une virgule)</translation>
+        <translation>Extensions Markdown (séparées par une virgule)</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Enable synchronized scrolling for Markdown</source>
+        <translation>Activer le défilement synchronisé pour Markdown</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
@@ -52,6 +67,11 @@
         <source>Tabulation width</source>
         <translation>Largeur de tabulation</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Draw vertical line at column</source>
+        <translation>Dessiner une ligne verticale sur la colonne</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Interface</source>
@@ -72,26 +92,6 @@
         <source>Help</source>
         <translation>Aide</translation>
     </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Use live preview by default</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Enable synchronized scrolling for Markdown</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Draw vertical line at column</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Automatically open last documents on startup</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
@@ -124,7 +124,7 @@
     <message>
         <location filename="fakevimeditor.py" line="64"/>
         <source>No write since last change (add ! to override)</source>
-        <translation>Aucune modification depuis la dernière sauvegarde (ajoutez ! pour écraser)</translation>
+        <translation>Pas d&apos;écriture depuis le dernier changement (ajoutez ! pour écraser)</translation>
     </message>
     <message>
         <location filename="fakevimeditor.py" line="121"/>
@@ -137,12 +137,12 @@
     <message>
         <location filename="editor.py" line="295"/>
         <source>Save image</source>
-        <translation type="unfinished"></translation>
+        <translation>Enregistrer l&apos;image</translation>
     </message>
     <message>
         <location filename="editor.py" line="295"/>
         <source>Images (*.png *.jpg)</source>
-        <translation type="unfinished"></translation>
+        <translation>Images (*.png *.jpg)</translation>
     </message>
 </context>
 <context>
@@ -173,7 +173,7 @@
     <message>
         <location filename="window.py" line="89"/>
         <source>Search toolbar</source>
-        <translation>Barre d&apos;outil de recherche</translation>
+        <translation>Barre d&apos;outil Recherche</translation>
     </message>
     <message>
         <location filename="window.py" line="93"/>
@@ -193,7 +193,7 @@
     <message>
         <location filename="window.py" line="1096"/>
         <source>Reload</source>
-        <translation>Recherger</translation>
+        <translation>Recharger</translation>
     </message>
     <message>
         <location filename="window.py" line="105"/>
@@ -230,6 +230,16 @@
         <source>View HTML code</source>
         <translation>Voir le code HTML</translation>
     </message>
+    <message>
+        <location filename="window.py" line="121"/>
+        <source>Change editor font</source>
+        <translation>Changer la police de l&apos;éditeur</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="123"/>
+        <source>Change preview font</source>
+        <translation>Changer la police de l&apos;aperçu</translation>
+    </message>
     <message>
         <location filename="window.py" line="125"/>
         <source>Find text</source>
@@ -243,12 +253,12 @@
     <message>
         <location filename="window.py" line="139"/>
         <source>Live preview</source>
-        <translation>Aperçu direct</translation>
+        <translation>Aperçu dynamique</translation>
     </message>
     <message>
         <location filename="window.py" line="144"/>
         <source>Table editing mode</source>
-        <translation>Mode table</translation>
+        <translation>Mode édition table</translation>
     </message>
     <message>
         <location filename="window.py" line="148"/>
@@ -310,6 +320,11 @@
         <source>Use WebKit renderer</source>
         <translation>Utiliser le rendu de WebKit</translation>
     </message>
+    <message>
+        <location filename="window.py" line="191"/>
+        <source>Use WebEngine (Chromium) renderer</source>
+        <translation>Utiliser le rendu de WebEngine (Chromium)</translation>
+    </message>
     <message>
         <location filename="window.py" line="196"/>
         <source>Show directory</source>
@@ -325,6 +340,21 @@
         <source>Previous</source>
         <translation>Précédent</translation>
     </message>
+    <message>
+        <location filename="window.py" line="201"/>
+        <source>Replace</source>
+        <translation>Remplacer</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="203"/>
+        <source>Replace all</source>
+        <translation>Remplacer tout</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="207"/>
+        <source>Close</source>
+        <translation>Fermer</translation>
+    </message>
     <message>
         <location filename="window.py" line="210"/>
         <source>Get help online</source>
@@ -355,6 +385,11 @@
         <source>Underline</source>
         <translation>Souligné</translation>
     </message>
+    <message>
+        <location filename="window.py" line="299"/>
+        <source>Formatting</source>
+        <translation>Formatage</translation>
+    </message>
     <message>
         <location filename="window.py" line="245"/>
         <source>Symbols</source>
@@ -395,16 +430,16 @@
         <source>Default markup</source>
         <translation>Balisage par défaut</translation>
     </message>
-    <message>
-        <location filename="window.py" line="299"/>
-        <source>Formatting</source>
-        <translation>Formatage</translation>
-    </message>
     <message>
         <location filename="window.py" line="339"/>
         <source>Search</source>
         <translation>Rechercher</translation>
     </message>
+    <message>
+        <location filename="window.py" line="342"/>
+        <source>Replace with</source>
+        <translation>Remplacer avec</translation>
+    </message>
     <message>
         <location filename="window.py" line="344"/>
         <source>Case sensitively</source>
@@ -438,7 +473,7 @@
     <message>
         <location filename="window.py" line="818"/>
         <source>Select file encoding from the list:</source>
-        <translation>Choisir l&apos;encodage du fichier dans la liste</translation>
+        <translation>Choisir l&apos;encodage du fichier dans la liste:</translation>
     </message>
     <message>
         <location filename="window.py" line="839"/>
@@ -449,13 +484,18 @@
         <location filename="window.py" line="842"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
-        <translation>Fichers %s</translation>
+        <translation>Fichiers %s</translation>
     </message>
     <message>
         <location filename="window.py" line="919"/>
         <source>Save file</source>
         <translation>Enregistrer le fichier</translation>
     </message>
+    <message>
+        <location filename="window.py" line="860"/>
+        <source>Cannot save to file which is open in another tab!</source>
+        <translation>Impossible d&apos;enregistrer un fichier ouvert dans un autre onglet!</translation>
+    </message>
     <message>
         <location filename="window.py" line="884"/>
         <source>Cannot save to file because it is read-only!</source>
@@ -501,6 +541,21 @@
         <source>Failed to execute the command:</source>
         <translation>Échec lors de l&apos;exécution de la commande :</translation>
     </message>
+    <message>
+        <location filename="window.py" line="1039"/>
+        <source>Alt text</source>
+        <translation>Texte alternatif</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1040"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1040"/>
+        <source>Link text</source>
+        <translation>Texte du lien</translation>
+    </message>
     <message>
         <location filename="window.py" line="1080"/>
         <source>This file has been deleted by other application.
@@ -534,6 +589,11 @@ Voulez vous enregistrer vos changements ?</translation>
         <source>HTML code</source>
         <translation>Code HTML</translation>
     </message>
+    <message>
+        <location filename="window.py" line="1156"/>
+        <source>ReText %s (using PyMarkups %s)</source>
+        <translation>ReText %s (utilisant PyMarkups %s)</translation>
+    </message>
     <message>
         <location filename="window.py" line="1156"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
@@ -559,65 +619,5 @@ Voulez vous enregistrer vos changements ?</translation>
         <source>reStructuredText syntax</source>
         <translation>Syntaxe reStructuredText</translation>
     </message>
-    <message>
-        <location filename="window.py" line="121"/>
-        <source>Change editor font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="123"/>
-        <source>Change preview font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1156"/>
-        <source>ReText %s (using PyMarkups %s)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="207"/>
-        <source>Close</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1039"/>
-        <source>Alt text</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1040"/>
-        <source>URL</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1040"/>
-        <source>Link text</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="201"/>
-        <source>Replace</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="203"/>
-        <source>Replace all</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="342"/>
-        <source>Replace with</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="860"/>
-        <source>Cannot save to file which is open in another tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="191"/>
-        <source>Use WebEngine (Chromium) renderer</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 </TS>
