@@ -12,11 +12,21 @@
         <source>Automatically save documents</source>
         <translation>Salvar documentos automaticamente</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Automatically open last documents on startup</source>
+        <translation>Abrir últimos documentos automaticamente na inicialização</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Restore window geometry</source>
         <translation>Restaurar a geometria da janela</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Use live preview by default</source>
+        <translation>Utilizar a visualização automática como padrão</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Open external links in ReText window</source>
@@ -27,6 +37,11 @@
         <source>Markdown syntax extensions (comma-separated)</source>
         <translation>Extensões de sintáxe Markdown (separadas por vírgulas)</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Enable synchronized scrolling for Markdown</source>
+        <translation>Ativar rolagem sincronizada para Markdown</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Editor</source>
@@ -52,6 +67,11 @@
         <source>Tabulation width</source>
         <translation>Tamanho da tabulação</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Draw vertical line at column</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Interface</source>
@@ -72,26 +92,6 @@
         <source>Help</source>
         <translation>Ajuda</translation>
     </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Use live preview by default</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Enable synchronized scrolling for Markdown</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Draw vertical line at column</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Automatically open last documents on startup</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
@@ -137,12 +137,12 @@
     <message>
         <location filename="editor.py" line="295"/>
         <source>Save image</source>
-        <translation type="unfinished"></translation>
+        <translation>Salvar imagem</translation>
     </message>
     <message>
         <location filename="editor.py" line="295"/>
         <source>Images (*.png *.jpg)</source>
-        <translation type="unfinished"></translation>
+        <translation>Imagens (*.png *.jpg)</translation>
     </message>
 </context>
 <context>
@@ -155,7 +155,7 @@
     <message>
         <location filename="tab.py" line="188"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
-        <translation>Não foi possível analisar conteúdo do arquivo, verifique se você tem o &lt;a href=&quot;%s&quot;&gt;modulo necessário&lt;/a&gt; instalado!</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -258,7 +258,7 @@
     <message>
         <location filename="window.py" line="144"/>
         <source>Table editing mode</source>
-        <translation>Modo de entrada de tabela</translation>
+        <translation>Modo de edição de tabelas</translation>
     </message>
     <message>
         <location filename="window.py" line="148"/>
@@ -320,6 +320,11 @@
         <source>Use WebKit renderer</source>
         <translation>Utilizar renderizador WebKit</translation>
     </message>
+    <message>
+        <location filename="window.py" line="191"/>
+        <source>Use WebEngine (Chromium) renderer</source>
+        <translation>Utilizar renderizador WebEngine (Chromium)</translation>
+    </message>
     <message>
         <location filename="window.py" line="196"/>
         <source>Show directory</source>
@@ -335,6 +340,21 @@
         <source>Previous</source>
         <translation>Anterior</translation>
     </message>
+    <message>
+        <location filename="window.py" line="201"/>
+        <source>Replace</source>
+        <translation>Substituir</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="203"/>
+        <source>Replace all</source>
+        <translation>Substituir todos</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="207"/>
+        <source>Close</source>
+        <translation>Fechar</translation>
+    </message>
     <message>
         <location filename="window.py" line="210"/>
         <source>Get help online</source>
@@ -365,6 +385,11 @@
         <source>Underline</source>
         <translation>Sublinhado</translation>
     </message>
+    <message>
+        <location filename="window.py" line="299"/>
+        <source>Formatting</source>
+        <translation>Formatar</translation>
+    </message>
     <message>
         <location filename="window.py" line="245"/>
         <source>Symbols</source>
@@ -405,16 +430,16 @@
         <source>Default markup</source>
         <translation>Marcação padrão</translation>
     </message>
-    <message>
-        <location filename="window.py" line="299"/>
-        <source>Formatting</source>
-        <translation>Formatar</translation>
-    </message>
     <message>
         <location filename="window.py" line="339"/>
         <source>Search</source>
         <translation>Pesquisar</translation>
     </message>
+    <message>
+        <location filename="window.py" line="342"/>
+        <source>Replace with</source>
+        <translation>Substituir por</translation>
+    </message>
     <message>
         <location filename="window.py" line="344"/>
         <source>Case sensitively</source>
@@ -466,6 +491,11 @@
         <source>Save file</source>
         <translation>Salvar arquivo</translation>
     </message>
+    <message>
+        <location filename="window.py" line="860"/>
+        <source>Cannot save to file which is open in another tab!</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="window.py" line="884"/>
         <source>Cannot save to file because it is read-only!</source>
@@ -511,6 +541,21 @@
         <source>Failed to execute the command:</source>
         <translation>Falha ao executar o comando:</translation>
     </message>
+    <message>
+        <location filename="window.py" line="1039"/>
+        <source>Alt text</source>
+        <translation>Texto alternativo</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1040"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1040"/>
+        <source>Link text</source>
+        <translation>Texto de link</translation>
+    </message>
     <message>
         <location filename="window.py" line="1080"/>
         <source>This file has been deleted by other application.
@@ -574,50 +619,5 @@ Deseja salvar as alterações?</translation>
         <source>reStructuredText syntax</source>
         <translation>Sintaxe reStructuredText</translation>
     </message>
-    <message>
-        <location filename="window.py" line="207"/>
-        <source>Close</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1039"/>
-        <source>Alt text</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1040"/>
-        <source>URL</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1040"/>
-        <source>Link text</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="201"/>
-        <source>Replace</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="203"/>
-        <source>Replace all</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="342"/>
-        <source>Replace with</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="860"/>
-        <source>Cannot save to file which is open in another tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="191"/>
-        <source>Use WebEngine (Chromium) renderer</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 </TS>
