@@ -12,11 +12,21 @@
         <source>Automatically save documents</source>
         <translation>Automatski sačuvaj dokumente</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Automatically open last documents on startup</source>
+        <translation>Na početku, automatski otvori poslednje dokumente</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Restore window geometry</source>
         <translation>Upamti geometriju prozora</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Use live preview by default</source>
+        <translation>Podrazumevano koristi živi pregled</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Open external links in ReText window</source>
@@ -25,7 +35,12 @@
     <message>
         <location filename="config.py" line="67"/>
         <source>Markdown syntax extensions (comma-separated)</source>
-        <translation>Proširenja sintakse Markdown (odvojeno zapetom)</translation>
+        <translation>Markdaun proširenja sintakse (odvojeno zapetom)</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Enable synchronized scrolling for Markdown</source>
+        <translation>Uključi sinhronizovano klizanje za Markdown</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
@@ -52,6 +67,11 @@
         <source>Tabulation width</source>
         <translation>Širina tabulacije</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Draw vertical line at column</source>
+        <translation>Iscrtaj vertikalnu liniju na koloni</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Interface</source>
@@ -72,26 +92,6 @@
         <source>Help</source>
         <translation>Pomoć</translation>
     </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Use live preview by default</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Enable synchronized scrolling for Markdown</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Draw vertical line at column</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Automatically open last documents on startup</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
@@ -137,12 +137,12 @@
     <message>
         <location filename="editor.py" line="295"/>
         <source>Save image</source>
-        <translation type="unfinished"></translation>
+        <translation>Sačuvaj sliku</translation>
     </message>
     <message>
         <location filename="editor.py" line="295"/>
         <source>Images (*.png *.jpg)</source>
-        <translation type="unfinished"></translation>
+        <translation>Slike (*.png *.jpg)</translation>
     </message>
 </context>
 <context>
@@ -155,7 +155,7 @@
     <message>
         <location filename="tab.py" line="188"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
-        <translation>Ne mogu da raščlanim sadržaj fajla, Proverite da li imate instaliran &lt;a href=&quot;%s&quot;&gt;neophodan modul&lt;/a&gt;!</translation>
+        <translation>Ne mogu da raščlanim sadržaj fajla. Proverite da li imate instaliran &lt;a href=&quot;%s&quot;&gt;neophodan modul&lt;/a&gt;!</translation>
     </message>
 </context>
 <context>
@@ -230,6 +230,16 @@
         <source>View HTML code</source>
         <translation>Pogledaj HTML kod</translation>
     </message>
+    <message>
+        <location filename="window.py" line="121"/>
+        <source>Change editor font</source>
+        <translation>Izmeni font uređivača</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="123"/>
+        <source>Change preview font</source>
+        <translation>Izmeni font pregleda</translation>
+    </message>
     <message>
         <location filename="window.py" line="125"/>
         <source>Find text</source>
@@ -248,7 +258,7 @@
     <message>
         <location filename="window.py" line="144"/>
         <source>Table editing mode</source>
-        <translation>Režim tabele</translation>
+        <translation>Režim uređivanja tabele</translation>
     </message>
     <message>
         <location filename="window.py" line="148"/>
@@ -310,6 +320,11 @@
         <source>Use WebKit renderer</source>
         <translation>Koristi WebKit iscrtavač</translation>
     </message>
+    <message>
+        <location filename="window.py" line="191"/>
+        <source>Use WebEngine (Chromium) renderer</source>
+        <translation>Koristi WebEngine (Chromium) iscrtavač</translation>
+    </message>
     <message>
         <location filename="window.py" line="196"/>
         <source>Show directory</source>
@@ -325,6 +340,21 @@
         <source>Previous</source>
         <translation>Prethodno</translation>
     </message>
+    <message>
+        <location filename="window.py" line="201"/>
+        <source>Replace</source>
+        <translation>Zameni</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="203"/>
+        <source>Replace all</source>
+        <translation>Zameni sve</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="207"/>
+        <source>Close</source>
+        <translation>Zatvori</translation>
+    </message>
     <message>
         <location filename="window.py" line="210"/>
         <source>Get help online</source>
@@ -333,7 +363,7 @@
     <message>
         <location filename="window.py" line="211"/>
         <source>About ReText</source>
-        <translation>O programu ReText</translation>
+        <translation>O ReText-u</translation>
     </message>
     <message>
         <location filename="window.py" line="214"/>
@@ -355,6 +385,11 @@
         <source>Underline</source>
         <translation>Podvučeno</translation>
     </message>
+    <message>
+        <location filename="window.py" line="299"/>
+        <source>Formatting</source>
+        <translation>Formatiranje</translation>
+    </message>
     <message>
         <location filename="window.py" line="245"/>
         <source>Symbols</source>
@@ -395,16 +430,16 @@
         <source>Default markup</source>
         <translation>Podrazumevana markacija</translation>
     </message>
-    <message>
-        <location filename="window.py" line="299"/>
-        <source>Formatting</source>
-        <translation>Formatiranje</translation>
-    </message>
     <message>
         <location filename="window.py" line="339"/>
         <source>Search</source>
         <translation>Traži</translation>
     </message>
+    <message>
+        <location filename="window.py" line="342"/>
+        <source>Replace with</source>
+        <translation>Zameni sa</translation>
+    </message>
     <message>
         <location filename="window.py" line="344"/>
         <source>Case sensitively</source>
@@ -456,6 +491,11 @@
         <source>Save file</source>
         <translation>Sačuvaj fajl</translation>
     </message>
+    <message>
+        <location filename="window.py" line="860"/>
+        <source>Cannot save to file which is open in another tab!</source>
+        <translation>Ne mogu da sačuvam jer je otvoren u drugom jezičku!</translation>
+    </message>
     <message>
         <location filename="window.py" line="884"/>
         <source>Cannot save to file because it is read-only!</source>
@@ -501,6 +541,21 @@
         <source>Failed to execute the command:</source>
         <translation>Neuspelo izvršenje komande:</translation>
     </message>
+    <message>
+        <location filename="window.py" line="1039"/>
+        <source>Alt text</source>
+        <translation>Alt tekst</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1040"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1040"/>
+        <source>Link text</source>
+        <translation>Tekst veze</translation>
+    </message>
     <message>
         <location filename="window.py" line="1080"/>
         <source>This file has been deleted by other application.
@@ -533,10 +588,15 @@ Do you want to save your changes?</source>
         <source>HTML code</source>
         <translation>HTML kod</translation>
     </message>
+    <message>
+        <location filename="window.py" line="1156"/>
+        <source>ReText %s (using PyMarkups %s)</source>
+        <translation>ReText %s (koristeći PyMarkups %s)</translation>
+    </message>
     <message>
         <location filename="window.py" line="1156"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
-        <translation>Jednostavan ali moćan uređivač za Markdown i reStructuredText</translation>
+        <translation>Jednostavan ali moćan uređivač za Markdaun i restruktuirani tekst</translation>
     </message>
     <message>
         <location filename="window.py" line="1156"/>
@@ -551,72 +611,12 @@ Do you want to save your changes?</source>
     <message>
         <location filename="window.py" line="1156"/>
         <source>Markdown syntax</source>
-        <translation>Sintaksa Markdown</translation>
+        <translation>Markdaun sintaksa</translation>
     </message>
     <message>
         <location filename="window.py" line="1156"/>
         <source>reStructuredText syntax</source>
-        <translation>Sintaksa reStructuredText</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="121"/>
-        <source>Change editor font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="123"/>
-        <source>Change preview font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1156"/>
-        <source>ReText %s (using PyMarkups %s)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="207"/>
-        <source>Close</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1039"/>
-        <source>Alt text</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1040"/>
-        <source>URL</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1040"/>
-        <source>Link text</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="201"/>
-        <source>Replace</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="203"/>
-        <source>Replace all</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="342"/>
-        <source>Replace with</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="860"/>
-        <source>Cannot save to file which is open in another tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="191"/>
-        <source>Use WebEngine (Chromium) renderer</source>
-        <translation type="unfinished"></translation>
+        <translation>Sintaksa restruktuiranog teksta</translation>
     </message>
 </context>
 </TS>
