@@ -2,7 +2,7 @@
 # vim: ts=8:sts=8:sw=8:noexpandtab
 
 # ReText
-# Copyright 2011-2015 Dmitry Shachnev
+# Copyright 2011-2017 Dmitry Shachnev
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,10 +24,11 @@ import markups
 from os import devnull
 from os.path import join
 from ReText import datadirs, settings, globalSettings, app_version
+from ReText import initializeDataDirs
 from ReText.window import ReTextWindow
 
 from PyQt5.QtCore import QFile, QFileInfo, QIODevice, QLibraryInfo, \
- QTextStream, QTranslator
+ QTextStream, QTranslator, Qt
 from PyQt5.QtWidgets import QApplication
 from PyQt5.QtNetwork import QNetworkProxyFactory
 
@@ -46,6 +47,9 @@ def main():
 		sys.stdout = open(devnull, 'w')
 		sys.stderr = open('stderr.log', 'w')
 
+	if hasattr(Qt, 'AA_ShareOpenGLContexts'):
+		# Needed for Qt WebEngine on Windows
+		QApplication.setAttribute(Qt.AA_ShareOpenGLContexts)
 	app = QApplication(sys.argv)
 	app.setOrganizationName("ReText project")
 	app.setApplicationName("ReText")
@@ -55,6 +59,7 @@ def main():
 	if hasattr(app, 'setDesktopFileName'): # available since Qt 5.7
 		app.setDesktopFileName('me.mitya57.ReText.desktop')
 	QNetworkProxyFactory.setUseSystemConfiguration(True)
+	initializeDataDirs()
 	RtTranslator = QTranslator()
 	for path in datadirs:
 		if RtTranslator.load('retext_' + globalSettings.uiLanguage,
@@ -78,6 +83,8 @@ def main():
 	fileNames = list(map(canonicalize, sys.argv[1:]))
 	previewMode = False
 	readStdIn = False
+	if globalSettings.openLastFilesOnStartup:
+		window.restoreLastOpenedFiles()
 	for fileName in fileNames:
 		if QFile.exists(fileName):
 			window.openFileWrapper(fileName)
@@ -91,6 +98,8 @@ def main():
 
 	inputData = ''
 	if readStdIn and sys.stdin is not None:
+		if sys.stdin.isatty():
+			print('Reading stdin, press ^D to end...')
 		inputData = sys.stdin.read()
 	if inputData or not window.tabWidget.count():
 		window.createNew(inputData)
